@@ -273,7 +273,8 @@ class TestCheckHostname(BaseTestCase):
             undercloud._check_hostname()
             mock_run_command.assert_called_with([
                 'sudo', '/bin/bash', '-c',
-                'sed -i "s/127.0.0.1\(\s*\)/127.0.0.1\\1test.hostname test /" '
+                'sed -i "s/127.0.0.1\\(\\s*\\)/'
+                '127.0.0.1\\1test.hostname test /" '
                 '/etc/hosts'],
                 name='hostname-to-etc-hosts')
 
@@ -290,7 +291,8 @@ class TestCheckHostname(BaseTestCase):
             undercloud._check_hostname()
             mock_run_command.assert_called_with([
                 'sudo', '/bin/bash', '-c',
-                'sed -i "s/127.0.0.1\(\s*\)/127.0.0.1\\1test.hostname test /" '
+                'sed -i "s/127.0.0.1\\(\\s*\\)/'
+                '127.0.0.1\\1test.hostname test /" '
                 '/etc/hosts'],
                 name='hostname-to-etc-hosts')
 
@@ -307,7 +309,7 @@ class TestCheckHostname(BaseTestCase):
             undercloud._check_hostname()
         mock_run_command.assert_called_with([
             'sudo', '/bin/bash', '-c',
-            'sed -i "s/127.0.0.1\(\s*\)/'
+            'sed -i "s/127.0.0.1\\(\\s*\\)/'
             '127.0.0.1\\1test-hostname.domain test-hostname /" '
             '/etc/hosts'],
             name='hostname-to-etc-hosts')
@@ -590,7 +592,8 @@ class TestGenerateEnvironment(BaseTestCase):
         env = undercloud._generate_environment('.')
         insecure_registries = json.loads(env['DOCKER_INSECURE_REGISTRIES'])
         # Spot check one service
-        self.assertEqual(['http://foo/bar:8787'], insecure_registries)
+        self.assertEqual(['192.168.24.1:8787', '192.168.24.3:8787',
+                         'http://foo/bar:8787'], insecure_registries)
 
     def test_generate_endpoints(self):
         env = undercloud._generate_environment('.')
